@@ -1,7 +1,7 @@
 #
 # This file is part of MooX-Options
 #
-# This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.
+# This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -13,7 +13,7 @@ package MooX::Options;
 use strict;
 use warnings;
 
-our $VERSION = '1.5';    # VERSION
+our $VERSION = '1.6';    # VERSION
 use Carp;
 use Data::Dumper;
 use Getopt::Long 2.38;
@@ -213,7 +213,7 @@ MooX::Options - add option keywords to your Moo object
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 MooX::Options
 
@@ -456,15 +456,15 @@ Ex :
 
 Any bugs or evolution can be submit here :
 
-L<Github|https://github.com/geistteufel/MooX-Options>
+L<Github|https://github.com/celogeek/MooX-Options>
 
 =head1 AUTHOR
 
-Geistteufel <geistteufel@celogeek.fr>
+celogeek <me@celogeek.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Geistteufel <geistteufel@celogeek.fr>.
+This software is copyright (c) 2011 by celogeek <me@celogeek.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
